|Build Status| |Coverage Status| |Documentation Status| |License: MIT|

QPU (Quantum Processing Unit)
==============================

A library for quantum processing units (IBM, D-Wave) containing common operations.


Note
----

This project has been set up using PyScaffold 3.1. For details and usage
information on PyScaffold see `https://pyscaffold.org/`_.

.. _`https://pyscaffold.org/`: https://pyscaffold.org/

.. |Build Status| image:: https://travis-ci.com/sea212/qpu.svg?branch=master
   :target: https://www.travis-ci.com/sea212/qpu
.. |Coverage Status| image:: https://coveralls.io/repos/github/sea212/qpu/badge.svg?branch=master
   :target: https://coveralls.io/github/sea212/qpu?branch=master
.. |Documentation Status| image:: https://readthedocs.org/projects/qpu/badge/?version=latest
   :target: https://qpu.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. |License: MIT| image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT
